DEstd_dataset: DEstd_dataset

DEstd_datasetR Documentation

DEstd_dataset

Description

A fisheries dataset for demonstrating Derived Effort Standardization (DEstd) method.

Usage

DEstd_dataset

Format

A data frame with 32 observations and 5 variables:

Year

Fishing year.

Gear

Sampled fishing gear used during the fishing operation.

Catch

Observed catch corresponding to the sampled effort.

Effort

Fishing effort expended.

Total_Catch

Estimated total annual catch (including gears for which effort is not known).

Details

The dataset contains annual fishing observations collected from multiple fishing gears along with catch, fishing effort, and total annual catch information. It is intended for illustrating the application of the DEstd() function in the FESta package.

See Also

DEstd

Examples

## Not run: 

library(FESta)
data("DEstd_dataset")
result<-DEstd(data=DEstd_dataset,year_col = "Year",gear_col = "Gear",
catch_col = "Catch",total_catch_col="Total_Catch", effort_col = "Effort")
print(result)

## End(Not run)


FESta documentation built on Aug. 20, 2026, 5:10 p.m.

Related to DEstd_dataset in FESta...