GLMstd_dataset: GLMstd_dataset

GLMstd_datasetR Documentation

GLMstd_dataset

Description

A fisheries dataset for demonstrating Generalized Linear Model (GLM) standardization method.

Usage

GLMstd_dataset

Format

A data frame with 1000 observations and 4 variables:

Year

Fishing year.

Gear

Fishing gear used during the fishing operation.

Effort

Fishing effort expended during the operation.

Catch

Observed catch obtained during the fishing operation.

Details

The dataset contains catch and effort observations collected over multiple years using different fishing gears. It is intended for illustrating the application of the GLMstd() function in the FESta package.

See Also

GLMstd

Examples

## Not run: 
library(FESta)
data('GLMstd_dataset')
# Single family
result1 <- GLMstd(
  data          = GLMstd_dataset,
  year_col="Year",
  catch_col     = "Catch",
  effort_col    = "Effort",
  fixed_effects = c("Year", "Gear"),
  family_type   = "gamma"
)
print(result1)

# Multiple families - comparison table + tiled plots
library(FESta)
data('GLMstd_dataset')
result2 <- GLMstd(
  data          = GLMstd_dataset,
  year_col      = "Year",
  catch_col     = "Catch",
  effort_col    = "Effort",
  fixed_effects = c("Year", "Gear"),
  family_type   = c("gamma", "lognormal", "tweedie", "poisson", "nbinom","gaussian")
)
print(result2)

## End(Not run)

FESta documentation built on Aug. 20, 2026, 5:10 p.m.

Related to GLMstd_dataset in FESta...