ORQGLMstd_dataset: ORQGLMstd_dataset

ORQGLMstd_datasetR Documentation

ORQGLMstd_dataset

Description

A fisheries dataset for demonstrating Generalized Linear Model (GLM) standardization method.

Usage

ORQGLMstd_dataset

Format

A data frame with 1000 observations and 4 variables:

Year

Fishing year.

Gear

Fishing gear used during the fishing operation.

Effort

Fishing effort expended during the operation.

Catch

Observed catch obtained during the fishing operation.

Details

The dataset contains catch and effort observations collected over multiple years using different fishing gears. It is intended for illustrating the application of the GLMstd() function in the FESta package.

See Also

ORQGLMstd

Examples

## Not run: 
library(FESta)
data("ORQGLMstd_dataset")
result<-ORQGLMstd(
  data  = ORQGLMstd_dataset,
  year_col="Year",
  catch_col      = "Catch",
  effort_col     = "Effort",
  fixed_effects  = c("Year", "Gear"),
  maxit          = 100
)
print(result)

## End(Not run)

FESta documentation built on Aug. 20, 2026, 5:10 p.m.