| SVstd | R Documentation |
This method selects a reference (standard) vessel and estimates the relative fishing power of all other vessels based on periods when both the standard and comparison vessels operated simultaneously.
The relative fishing power (RFP) for vessel i is calculated as:
RFP_i = \frac{C_i/E_i}{C_s/E_s}
where C_i and E_i are the total catch and effort of vessel
i, respectively, and C_s and E_s are the corresponding
catch and effort values for the selected standard vessel during the
same period.
The standardized annual CPUE index for year t is then computed as:
I_t = \frac{\sum_i C_{t,i}}
{\sum_i RFP_i E_{t,i}}
where C_{t,i} is the catch and E_{t,i} is the effort of
vessel i in year t.
SVstd(
data,
year_col,
vessel_col,
catch_col,
effort_col,
standard_vessel = NULL
)
data |
A data frame containing the columns of year, vessel, catch and effort. See the example dataset SVstd_dataset. |
year_col |
Specify the year column name (eg. "Year"). |
vessel_col |
Specify the vessel types column name (eg. "Vessel_Type"). |
catch_col |
Specify the catch column name (eg. "Catch"). |
effort_col |
Specify the effort column name (eg. "Effort"). |
standard_vessel |
Specify the reference (standard)
vessel name (eg. "Vessel1") used to estimate relative fishing power. If |
The output includes a summary table containing Year, Total Catch, Nominal CPUE, and Standardized CPUE. In addition, two plots are produced: Nominal CPUE versus Total Catch and Standardized CPUE versus Total Catch.
If catch column value of has zero value(s) then they will be replaced by minimum value of the catch column and further if effort column has zero values then the corresponding rows will be removed for doing the CPUE calculation.
Beverton, R.J.H., and Holt, S.J. (1957). On the Dynamics of Exploited Fish Populations. Fishery Investigations Series II, Volume XIX.
Varghese, E., Jayasankar, J., Sathianandan, T.V., Kuriakose, S., Mini, K.G., Gills, R., Muktha, M., Sreepriya, V. and Gopalakrishnan, A. (2023). A note on different methods for standardization of fishing efforts. Marine Fisheries Information Service, Technical and Extension Series, (257), 7-17.
Maunder, M.N., and Punt, A.E. (2004). Standardizing catch and effort data: a review of recent approaches. Fisheries Research, 70, 141-159.
Acknowledgements: The authors sincerely thank the Director, ICAR–Central Marine Fisheries Research Institute (ICAR-CMFRI), Kochi, for providing the necessary facilities and institutional support. The authors also gratefully acknowledge the support provided by the Indian Council of Agricultural Research (ICAR), Department of Agricultural Research and Education (DARE), Government of India, through the ICAR-National Fellow Project.
## Not run:
library(FESta)
data("SVstd_dataset")
result<-SVstd(data=SVstd_dataset,year_col ="Year", vessel_col = "Vessel",
catch_col = "Catch",effort_col = "Effort",standard_vessel = "V006")
print(result)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.