StdEffort_dataset: StdEffort_dataset

StdEffort_datasetR Documentation

StdEffort_dataset

Description

A list named "StdEffort_dataset" which contains three data frames has been given. The three data frames named "sp_catch", "tot_catch" and "effort" with each having the same dimension contains time series data (1997-2018) on species catch, total catch and fishing effort of 8 different fishing gears viz., mechanized trawlnet including multiday trawlnet(MTN), mechanized gillnet (MGN), non-mechanized gears (NM), outboard gillnet (OBGN), outboard ringseine (OBRS), outboard trawlnet (OBTN), some minor mechanized gears (MOTHERS)and some minor outboard gears (OBOTHS).

Usage

StdEffort_dataset

Format

A data frame with 22 rows and 9 variables:

species catch

Quantity, in tonnes (yearwise data).

total catch

Quantity, in tonnes (yearwise data).

effort

Actual Fishing Hours, in hours (yearwise data).

https://www.cmfri.org.in/fish-catch-estimates

See Also

StdEffort

Examples

## Not run: 
library(FESta)
data("StdEffort_dataset")
result<-StdEffort(
  sp_catch  = StdEffort_dataset$sp_catch,
  tot_catch = StdEffort_dataset$tot_catch,
  effort    = StdEffort_dataset$effort,
  meg       = 'OBGN'
)
print(result)

## End(Not run)


FESta documentation built on Aug. 20, 2026, 5:10 p.m.