| DEstd_dataset | R Documentation |
A fisheries dataset for demonstrating Derived Effort Standardization (DEstd) method.
DEstd_dataset
A data frame with 32 observations and 5 variables:
Fishing year.
Sampled fishing gear used during the fishing operation.
Observed catch corresponding to the sampled effort.
Fishing effort expended.
Estimated total annual catch (including gears for which effort is not known).
The dataset contains annual fishing observations collected
from multiple fishing gears along with catch, fishing effort,
and total annual catch information. It is intended for
illustrating the application of the DEstd() function
in the FESta package.
DEstd
## Not run:
library(FESta)
data("DEstd_dataset")
result<-DEstd(data=DEstd_dataset,year_col = "Year",gear_col = "Gear",
catch_col = "Catch",total_catch_col="Total_Catch", effort_col = "Effort")
print(result)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.