| MGMSstd | R Documentation |
The Multigear Mean Standardization (MGMS) method was proposed by Gibson-Reinemer et al. (2017) to combine CPUE data collected using different sampling gears into a common relative scale suitable for community analyses. Initially, CPUE values are expressed as relative abundance:
RA_{ij}=
\frac{c_{ij}/e}
{TC_j/e}
where
c_{ij} is the catch of species i in year (or sample) j.
e is the sampling effort.
TC_j is the total catch of all species in year (or sample) j.
To preserve both within-sample and among-sample abundance patterns, the total CPUE of each sample is standardized by the mean total CPUE across all samples:
MSC_{ij}
=
\frac{c_{ij}/e}{TC_j/e}
\times
\frac{TC_j/e}{\overline{TC}/e}
which simplifies to
MSC_{ij}
=
\frac{c_{ij}/e}
{\overline{TC}/e}
where
\overline{TC}/e
is the mean total catch per unit effort.
MGMSstd(data, year_col, gear_col, species_col, cpue_col)
data |
A data frame containing year, gear, species, and CPUE columns. |
year_col |
Specify the year column name (eg. "Year"). |
gear_col |
Specify the gear types column name (eg. "Gears"). |
species_col |
Specify the species column name (eg. "Species"). |
cpue_col |
Specify the CPUE column name (eg. "CPUE_value"). |
The function produces:
Gear-specific standardized CPUE tables.
A multiline plot of total standardized CPUE by gear.
CPUE should not contain zero values, if still zero values are present then all are replaced with minimum CPUE value.
Gibson-Reinemer, D. K., Ickes, B. S., & Chick, J. H. (2017). Development and assessment of a new method for combining catch per unit effort data from different fish sampling gears: multigear mean standardization (MGMS). Canadian Journal of Fisheries and Aquatic Sciences, 74(1), 8–14. https://doi.org/10.1139/cjfas-2016-0003
Varghese, E., Jayasankar, J., Sathianandan, T.V., Kuriakose, S., Mini, K.G., Gills, R., Muktha, M., Sreepriya, V. and Gopalakrishnan, A. (2023). A note on different methods for standardization of fishing efforts. Marine Fisheries Information Service, Technical and Extension Series, (257), 7-17.
Acknowledgements: The authors sincerely thank the Director, ICAR–Central Marine Fisheries Research Institute (ICAR-CMFRI), Kochi, for providing the necessary facilities and institutional support. The authors also gratefully acknowledge the support provided by the Indian Council of Agricultural Research (ICAR), Department of Agricultural Research and Education (DARE), Government of India, through the ICAR-National Fellow Project.
## Not run:
library(FESta)
data("MGMSstd_dataset")
result <- MGMSstd(
data = MGMSstd_dataset,
year_col = "Year",
gear_col = "Gear",
species_col = "Species",
cpue_col = "CPUE"
)
print(result)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.