| REstd | R Documentation |
Standardizes fishing effort by adjusting for differences in fishing power among vessel types relative to a selected standard vessel. The method estimates the relative fishing power of each vessel type from observed CPUE values and converts raw fishing effort into a common-efficiency effort scale.
Relative fishing power is calculated as:
PA(i)=\frac{CPUE(i)}
{CPUE(standard)}
where CPUE(i) is the catch-per-unit-effort of vessel type i
and CPUE(standard) is the CPUE of the selected standard vessel.
Standardized effort is then computed as:
E_{std}
=
\sum_i
\left[
PA(i)\times N(i)\times d(i)
\right]
where N(i) is the number of boats and d(i) is the average
number of fishing days for vessel type i.
REstd(
data,
year_col,
vessel_col,
boats_col,
days_col,
cpue_col,
standard_vessel
)
data |
A data frame containing the columns of year, vessel information, number of boats, days of fishing and CPUE. See the example dataset REstd_dataset. |
year_col |
Specify the year column name (eg. "Year"). |
vessel_col |
Specify the vessel types column name (eg. "Vessel_Type"). |
boats_col |
Specify the number of boats column name (eg. "Number_of_Boats"). |
days_col |
Specify the number of fishing days column name (eg. "Avg_Fishing_Days"). |
cpue_col |
Specify the CPUE column name (eg. "CPUE"). |
standard_vessel |
Specifying the reference vessel based on which relative fishing power will be calculated. If NULL, the function automatically selects a standard vessel from the available data. |
A data frame containing year-wise standardized effort (used as standardized CPUE index) along with a printed summary table and a dual-axis trend plot showing standardized CPUE and mean relative fishing power by year.
CPUE should not contain zero values, if still zero values are present then all are replaced with minimum CPUE value.
Varghese, E., Jayasankar, J., Sathianandan, T.V., Kuriakose, S., Mini, K.G., Gills, R., Muktha, M., Sreepriya, V. and Gopalakrishnan, A. (2023). A note on different methods for standardization of fishing efforts. Marine Fisheries Information Service, Technical and Extension Series, (257), 7-17.
Robson, D.S. (1966). Estimation of the relative fishing power of individual ships. ICNAF Research Bulletin, 3, 5-14.
Sparre, P., and Venema, S.C. (1992). Introduction to Tropical Fish Stock Assessment. FAO Fisheries Technical Paper No. 306/1, 376 pp.
Acknowledgements: The authors sincerely thank the Director, ICAR–Central Marine Fisheries Research Institute (ICAR-CMFRI), Kochi, for providing the necessary facilities and institutional support. The authors also gratefully acknowledge the support provided by the Indian Council of Agricultural Research (ICAR), Department of Agricultural Research and Education (DARE), Government of India, through the ICAR-National Fellow Project.
## Not run:
library(FESta)
data("REstd_dataset")
result<-REstd(data = REstd_dataset, year_col = "Year", vessel_col = "Vessel",
boats_col = "Boats", days_col = "Days",
cpue_col = "CPUE", standard_vessel = 'A')
print(result)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.