| StdEffort_dataset | R Documentation |
A list named "StdEffort_dataset" which contains three data frames has been given. The three data frames named "sp_catch", "tot_catch" and "effort" with each having the same dimension contains time series data (1997-2018) on species catch, total catch and fishing effort of 8 different fishing gears viz., mechanized trawlnet including multiday trawlnet(MTN), mechanized gillnet (MGN), non-mechanized gears (NM), outboard gillnet (OBGN), outboard ringseine (OBRS), outboard trawlnet (OBTN), some minor mechanized gears (MOTHERS)and some minor outboard gears (OBOTHS).
StdEffort_dataset
A data frame with 22 rows and 9 variables:
Quantity, in tonnes (yearwise data).
Quantity, in tonnes (yearwise data).
Actual Fishing Hours, in hours (yearwise data).
https://www.cmfri.org.in/fish-catch-estimates
StdEffort
## Not run:
library(FESta)
data("StdEffort_dataset")
result<-StdEffort(
sp_catch = StdEffort_dataset$sp_catch,
tot_catch = StdEffort_dataset$tot_catch,
effort = StdEffort_dataset$effort,
meg = 'OBGN'
)
print(result)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.